@@ -541,7 +541,8 @@ class EBML(FieldSet):
                     yield EBML(self, val)
 
 class MkvFile(Parser):
-    tags = {
+    EBML_SIGNATURE = 0x1A45DFA3
+    PARSER_TAGS = {
         "id": "matroska",
         "category": "container",
         "file_ext": ("mka", "mkv"),
@@ -553,7 +554,7 @@ class MkvFile(Parser):
     endian = BIG_ENDIAN
 
     def validate(self):
-        if self.stream.readBits(0, 32, self.endian) != ebml.keys()[0]:
+        if self.stream.readBits(0, 32, self.endian) != self.EBML_SIGNATURE:
             return False
         try:
             first = self[0]
