@@ -11,25 +11,41 @@ from hachoir_core.field import (FieldSet, ParserError,
     PaddingBytes, createPaddingField)
 from hachoir_core.endian import LITTLE_ENDIAN, BIG_ENDIAN, NETWORK_ENDIAN
 from hachoir_core.text_handler import textHandler, hexadecimal
-from hachoir_core.tools import paddingSize
 from hachoir_core.tools import createDict
 
 MAX_COUNT = 1000
 
+def rationalFactory(class_name, size, field_class):
+    class Rational(FieldSet):
+        static_size = size
+
+        def createFields(self):
+            yield field_class(self, "numerator")
+            yield field_class(self, "denominator")
+
+        def createValue(self):
+            return float(self["numerator"].value) / self["denominator"].value
+    cls = Rational
+    cls.__name__ = class_name
+    return cls
+
+RationalInt32 = rationalFactory("RationalInt32", 64, Int32)
+RationalUInt32 = rationalFactory("RationalUInt32", 64, UInt32)
+
 class BasicIFDEntry(FieldSet):
     TYPE_BYTE = 0
     TYPE_UNDEFINED = 7
     TYPE_RATIONAL = 5
     TYPE_SIGNED_RATIONAL = 10
     TYPE_INFO = {
-         1: ((1, UInt8), "BYTE (8 bits)"),
-         2: ((1, String), "ASCII (8 bits)"),
-         3: ((1, UInt16), "SHORT (16 bits)"),
-         4: ((1, UInt32), "LONG (32 bits)"),
-         5: ((2, UInt32), "RATIONAL (2x LONG, 64 bits)"),
-         7: ((1, Bytes), "UNDEFINED (8 bits)"),
-         9: ((1, Int32), "SIGNED LONG (32 bits)"),
-        10: ((2, Int32), "SRATIONAL (2x SIGNED LONGs, 64 bits)"),
+         1: (UInt8, "BYTE (8 bits)"),
+         2: (String, "ASCII (8 bits)"),
+         3: (UInt16, "SHORT (16 bits)"),
+         4: (UInt32, "LONG (32 bits)"),
+         5: (RationalUInt32, "RATIONAL (2x LONG, 64 bits)"),
+         7: (Bytes, "UNDEFINED (8 bits)"),
+         9: (Int32, "SIGNED LONG (32 bits)"),
+        10: (RationalInt32, "SRATIONAL (2x SIGNED LONGs, 64 bits)"),
     }
     ENTRY_FORMAT = createDict(TYPE_INFO, 0)
     TYPE_NAME = createDict(TYPE_INFO, 1)
@@ -44,7 +60,9 @@ class BasicIFDEntry(FieldSet):
         value_size, array_size = self.getSizes()
 
         # Get offset/value
-        if value_size <= 32:
+        if not value_size:
+            yield PaddingBytes(self, "padding", 4)
+        elif value_size <= 32:
             if 1 < array_size:
                 name = "value[]"
             else:
@@ -74,13 +92,10 @@ class BasicIFDEntry(FieldSet):
         array_size in number of items.
         """
         # Create format
-        format = self.ENTRY_FORMAT.get(self["type"].value, (1, Bytes))
-        count = self["count"].value * format[0]
-        if count == 0:
-            raise ParserError("Invalid count value")
-        self.value_cls = format[1]
+        self.value_cls = self.ENTRY_FORMAT.get(self["type"].value, Bytes)
 
         # Set size
+        count = self["count"].value
         if self.value_cls in (String, Bytes):
             return 8 * count, 1
         else:
@@ -93,6 +108,15 @@ class ExifEntry(BasicIFDEntry):
     TAG_WIDTH = 0xA002
     TAG_HEIGHT = 0xA003
 
+    TAG_GPS_LATITUDE_REF = 0x0001
+    TAG_GPS_LATITUDE = 0x0002
+    TAG_GPS_LONGITUDE_REF = 0x0003
+    TAG_GPS_LONGITUDE = 0x0004
+    TAG_GPS_ALTITUDE_REF = 0x0005
+    TAG_GPS_ALTITUDE = 0x0006
+    TAG_GPS_TIMESTAMP = 0x0007
+    TAG_GPS_DATESTAMP = 0x001d
+
     TAG_IMG_TITLE = 0x010e
     TAG_FILE_TIMESTAMP = 0x0132
     TAG_SOFTWARE = 0x0131
@@ -106,6 +130,39 @@ class ExifEntry(BasicIFDEntry):
     TAG_USER_COMMENT = 0x9286
 
     TAG_NAME = {
+        # GPS
+        0x0000: "GPS version ID",
+        0x0001: "GPS latitude ref",
+        0x0002: "GPS latitude",
+        0x0003: "GPS longitude ref",
+        0x0004: "GPS longitude",
+        0x0005: "GPS altitude ref",
+        0x0006: "GPS altitude",
+        0x0007: "GPS timestamp",
+        0x0008: "GPS satellites",
+        0x0009: "GPS status",
+        0x000a: "GPS measure mode",
+        0x000b: "GPS DOP",
+        0x000c: "GPS speed ref",
+        0x000d: "GPS speed",
+        0x000e: "GPS track ref",
+        0x000f: "GPS track",
+        0x0010: "GPS img direction ref",
+        0x0011: "GPS img direction",
+        0x0012: "GPS map datum",
+        0x0013: "GPS dest latitude ref",
+        0x0014: "GPS dest latitude",
+        0x0015: "GPS dest longitude ref",
+        0x0016: "GPS dest longitude",
+        0x0017: "GPS dest bearing ref",
+        0x0018: "GPS dest bearing",
+        0x0019: "GPS dest distance ref",
+        0x001a: "GPS dest distance",
+        0x001b: "GPS processing method",
+        0x001c: "GPS area information",
+        0x001d: "GPS datestamp",
+        0x001e: "GPS differential",
+
         0x0100: "Image width",
         0x0101: "Image height",
         0x0102: "Number of bits per component",
@@ -219,21 +276,21 @@ class ExifIFD(FieldSet):
         yield UInt16(self, "count", "Number of entries")
         entries = []
         next_chunk_offset = None
-        while True:
+        count = self["count"].value
+        if not count:
+            return
+        while count:
             addr = self.absolute_address + self.current_size
             next = self.stream.readBits(addr, 32, NETWORK_ENDIAN)
             if next in (0, 0xF0000000):
                 break
             entry = ExifEntry(self, "entry[]")
             yield entry
-            if entry["tag"].value in (entry.EXIF_IFD_POINTER, entry.OFFSET_JPEG_SOI):
+            if entry["tag"].value in (ExifEntry.EXIF_IFD_POINTER, ExifEntry.OFFSET_JPEG_SOI):
                 next_chunk_offset = entry["value"].value + offset_diff
-                if entry["tag"].value == entry.OFFSET_JPEG_SOI:
-                   self.parent.jpeg_soi = next_chunk_offset
-                break
-
             if 32 < entry.getSizes()[0]:
                 entries.append(entry)
+            count -= 1
         yield UInt32(self, "next", "Next IFD offset")
         try:
             entries.sort( sortExifEntry )
@@ -246,6 +303,8 @@ class ExifIFD(FieldSet):
                 yield padding
 
             value_size, array_size = entry.getSizes()
+            if not array_size:
+                continue
             cls = entry.value_cls
             if 1 < array_size:
                 name = "value_%s[]" % entry.name
@@ -266,11 +325,6 @@ class ExifIFD(FieldSet):
             padding = self.seek(next_chunk_offset)
             if padding is not None:
                 yield padding
-        else:
-            next_addr = (self.address + self.current_size)/8 + 2
-            if (next_addr % 4) != 0 and self["../whatsthis"].value == 8:
-                size = paddingSize(next_addr, 4)
-                yield PaddingBytes(self, "padding", 2)
 
     def createDescription(self):
         return "Exif IFD (id %s)" % self["id"].value
@@ -278,7 +332,6 @@ class ExifIFD(FieldSet):
 class Exif(FieldSet):
     def createFields(self):
         # Headers
-        self.jpeg_soi = None
         yield String(self, "header", 6, "Header (Exif\\0\\0)", charset="ASCII")
         if self["header"].value != "Exif\0\0":
             raise ParserError("Invalid EXIF signature!")
